
package io.platform.log.web.controller.rest;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.platform.base.common.annotation.SysLog;
import io.platform.base.common.controller.AbstractController;
import io.platform.base.common.utils.ExecuteResult;
import io.platform.base.common.utils.R;
import io.platform.base.common.validator.ValidatorUtils;
import io.platform.log.dto.SysFunctionLogDto;
import io.platform.log.web.remote.SysFunctionLogServiceRemote;
import org.springframework.web.bind.annotation.*;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;



import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/log/sysFunctionLog")
public class SysFunctionLogRestController extends AbstractController {

    @Autowired
	private SysFunctionLogServiceRemote sysFunctionLogServiceRemote;
	
	/**
	 * 所有列表
	 */
	@RequestMapping("/list")
	@RequiresPermissions("log:sysFunctionLog:list")
	public R list(@RequestParam Map<String, Object> params){
		//查询列表数据
		return R.ok().put("list", sysFunctionLogServiceRemote.getList(params));
	}

	/**
	 * 分页列表
	 */
	@RequestMapping("/page")
	@RequiresPermissions("log:sysFunctionLog:page")
	public R page(Page page, SysFunctionLogDto sysFunctionLogDto){
		return R.ok().put("page", sysFunctionLogServiceRemote.getPage(page,sysFunctionLogDto));
	}
	/**
	 * 信息
	 */
	@RequestMapping("/info/{id}")
	@RequiresPermissions("log:sysFunctionLog:info")
	public R info(@PathVariable("id") Long id){
		SysFunctionLogDto sysFunctionLogDto = sysFunctionLogServiceRemote.getOne(id);
		return R.ok().put("sysFunctionLogDto", sysFunctionLogDto);
	}
	
	/**
	 * 保存
	 */
	@SysLog("保存")
	@RequestMapping("/save")
	@RequiresPermissions("log:sysFunctionLog:save")
	public R save(@RequestBody SysFunctionLogDto sysFunctionLogDto){
        ValidatorUtils.validateEntity(sysFunctionLogDto);
        ExecuteResult<String> result= sysFunctionLogServiceRemote.save(sysFunctionLogDto);
        if(result.isSuccess()){
            return R.ok(result.getSuccessMessage());
        }else{
            return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 修改
	 */
	@SysLog("修改")
	@RequestMapping("/update")
	@RequiresPermissions("log:sysFunctionLog:edit")
	public R update(@RequestBody SysFunctionLogDto sysFunctionLogDto){
        ValidatorUtils.validateEntity(sysFunctionLogDto);
        ExecuteResult<String> result= sysFunctionLogServiceRemote.update(sysFunctionLogDto);
        if(result.isSuccess()){
        	return R.ok(result.getSuccessMessage());
        }else{
        	return R.error(result.getErrorMessages().get(0));
        }
	}
	
	/**
	 * 删除
	 */
	@SysLog("删除")
	@RequestMapping("/delete")
	@RequiresPermissions("log:sysFunctionLog:delete")
	public R delete(@RequestBody List<Long> ids){
        ExecuteResult<String> result= sysFunctionLogServiceRemote.deleteBatch(ids);
        if(result.isSuccess()){
        	return R.ok(result.getSuccessMessage());
        }else{
        	return R.error(result.getErrorMessages().get(0));
        }
	}

}
