package io.platform.config.aspect;


import java.lang.reflect.Method;
import java.sql.SQLException;
import java.util.Date;


import com.alibaba.dubbo.config.annotation.Reference;
import com.alibaba.fastjson.JSON;
import io.jsonwebtoken.Claims;
import io.platform.base.common.utils.IPUtils;
import io.platform.base.common.utils.JwtUtils;
import io.platform.config.annotation.FuncLogAnno;
import io.platform.log.dto.SysFunctionLogDto;
import io.platform.log.service.client.api.SysFunctionLogServiceClient;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.reflect.MethodSignature;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;


/**
 * TODO
 *
 * Sopring Aop 实现日志记录
 *
 * @author shanxin
 * @version 1.0
 * @date 2020/10/29 13:36
 */
@Order(3)
@Component
@Aspect
public class LogAopAspcet {


    private Logger log = LoggerFactory.getLogger(getClass());

    @Resource
    public JwtUtils jwtUtils;


    @Reference(check = false)
    public SysFunctionLogServiceClient sysFunctionLogServiceClient;


    /**
     *
     * 环绕通知记录日志通过注解匹配到需要增加日志功能的方法
     * @param pjp
     * @return
     * @throws Throwable
     */
    @Around("@annotation(io.platform.config.annotation.FuncLogAnno)")
    public Object aroundAdvice(ProceedingJoinPoint pjp) throws Throwable {
        // 1.方法执行前的处理，相当于前置通知
        // 获取方法签名
        MethodSignature methodSignature = (MethodSignature) pjp.getSignature();
        // 获取方法
        Method method = methodSignature.getMethod();
        // 获取方法上面的注解
        FuncLogAnno logAnno = method.getAnnotation(FuncLogAnno.class);
        // 获取注解上的功能描述
        String operateType = logAnno.functionName();

        Object result = null;


        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest req = attributes.getRequest();

        // 日志对象
        SysFunctionLogDto sysFunctionLogDto = new SysFunctionLogDto();
        sysFunctionLogDto.setFunctionName(operateType);
        Long userId = null;
        String token = req.getParameter(jwtUtils.getHeader());
        if (null != token) {
            Claims claimByToken = jwtUtils.getClaimByToken(token);
            userId = Long.parseLong(claimByToken.getSubject());
        } else {
            userId = 0L;
        }
        String ipAddr = IPUtils.getIpAddr(req);
        sysFunctionLogDto.setAccountId(userId);
        sysFunctionLogDto.setIpAddress(ipAddr);
        //请求的参数
        Object[] args = pjp.getArgs();
        //将参数所在的数组转换成json
        String params = JSON.toJSONString(args);
        sysFunctionLogDto.setParamsJson(params);
        sysFunctionLogDto.setCreateTime(new Date());
        try {
            // 让代理方法执行
            result = pjp.proceed();
            // 2.相当于后置通知(方法成功执行之后走这里)
        } catch (SQLException e) {
            // 3.相当于异常通知部分
        } finally {
            // 4.相当于最终通知
            sysFunctionLogServiceClient.save(sysFunctionLogDto);
        }
        return null;
    }

}