
package io.platform.log.service.client.impl;

import com.alibaba.dubbo.config.annotation.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import io.platform.base.common.BaseServiceClient;
import io.platform.base.common.utils.ExecuteResult;

import io.platform.log.biz.entity.SysFunctionLog;
import io.platform.log.biz.service.SysFunctionLogService;
import io.platform.log.dto.SysFunctionLogDto;
import io.platform.log.service.client.api.SysFunctionLogServiceClient;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;



@Component
@Service()
public class SysFunctionLogServiceClientImpl extends BaseServiceClient<SysFunctionLog,SysFunctionLogDto> implements SysFunctionLogServiceClient {

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Resource
    private SysFunctionLogService sysFunctionLogService;

    @Override
    public SysFunctionLogDto queryObject(Long id) {
        SysFunctionLog sysFunctionLog = sysFunctionLogService.getById(id);
        SysFunctionLogDto sysFunctionLogDto = new SysFunctionLogDto();
        BeanUtils.copyProperties(sysFunctionLog,sysFunctionLogDto);
        return sysFunctionLogDto;
    }

    @Override
    public List<SysFunctionLogDto> queryList(Map<String, Object> map) {
        List<SysFunctionLog> sysFunctionLogList = sysFunctionLogService.selectByMap(map);
        return convertList(sysFunctionLogList,SysFunctionLogDto.class);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        QueryWrapper<SysFunctionLog> ew = new QueryWrapper<>();
        ew.allEq(map);
        return sysFunctionLogService.count(ew);
    }

    @Override
    public ExecuteResult<String> save(SysFunctionLogDto sysFunctionLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysFunctionLog sysFunctionLog = new SysFunctionLog();
            revert(sysFunctionLogDto,sysFunctionLog);
            boolean flag = sysFunctionLogService.save(sysFunctionLog);
            if(!flag){
                result.addErrorMessage("保存失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 保存错误：" + e.toString(), e);
            result.addErrorMessage("保存错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> update(SysFunctionLogDto sysFunctionLogDto) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            SysFunctionLog sysFunctionLog = new SysFunctionLog();
            revert(sysFunctionLogDto,sysFunctionLog);
            boolean flag = sysFunctionLogService.updateById(sysFunctionLog);
            if(!flag){
                result.addErrorMessage("更新失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 更新错误：" + e.toString(), e);
            result.addErrorMessage("更新错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> delete(Long id) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysFunctionLogService.removeById(id);
            if(!flag){
                result.addErrorMessage("删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public ExecuteResult<String> deleteBatch(List<Long> ids) {
        ExecuteResult<String> result = new ExecuteResult<String>();
        try{
            boolean flag = sysFunctionLogService.removeByIds(ids);
            if(!flag){
                result.addErrorMessage("批量删除失败。");
            }
        }
        catch (Exception e) {
            logger.error(" 删除错误：" + e.toString(), e);
            result.addErrorMessage("删除错误：" + e.toString());
        }
        return result;
    }

    @Override
    public Page<SysFunctionLogDto> getPage(Page<SysFunctionLogDto> pageDto,SysFunctionLogDto sysFunctionLogDto) {
        Page<SysFunctionLog> page = new Page<>(pageDto.getCurrent(),pageDto.getSize());

        page.setAsc(pageDto.ascs());
        page.setDesc(pageDto.descs());
        page.condition().putAll(pageDto.condition());

        SysFunctionLog sysFunctionLog = new SysFunctionLog();
        revert(sysFunctionLogDto,sysFunctionLog);

        QueryWrapper<SysFunctionLog> wrapper = new QueryWrapper<>();
        wrapper.setEntity(sysFunctionLog);

        List<SysFunctionLogDto> sysFunctionLogDtoList = convertList(sysFunctionLogService.page(page,wrapper).getRecords(),SysFunctionLogDto.class);
        pageDto.setTotal(sysFunctionLogService.count(wrapper));
        pageDto.setRecords(sysFunctionLogDtoList);
        return pageDto;
    }
}
